@@ -199,7 +199,7 @@ pub trait MockRequestMatcher: Send + Sync {
 /// requests with specific methods to responses.
 ///
 /// [`MockRequestMatcher`]: trait.MockRequestMatcher.html
-#[derive(Debug)]
+#[derive(Debug, Default)]
 pub struct MockRequestMethodMatcher {
     mappings: HashMap<Method, Result<String, Error>>,
 }
@@ -216,14 +216,6 @@ impl MockRequestMatcher for MockRequestMethodMatcher {
     }
 }
 
-impl Default for MockRequestMethodMatcher {
-    fn default() -> Self {
-        Self {
-            mappings: HashMap::new(),
-        }
-    }
-}
-
 impl MockRequestMethodMatcher {
     /// Maps all incoming requests with the given method such that their
     /// corresponding response will be `response`.
