@@ -475,7 +475,7 @@ fn consensus_state() {
                 vec![123, 185, 116, 225, 186, 64]
             );
             assert_eq!(
-                summary.timestamp.as_rfc3339(),
+                summary.timestamp.to_rfc3339(),
                 "2019-08-01T11:52:35.513572509Z"
             );
         }
@@ -502,7 +502,7 @@ fn consensus_state() {
                 vec![139, 94, 255, 254, 171, 205]
             );
             assert_eq!(
-                summary.timestamp.as_rfc3339(),
+                summary.timestamp.to_rfc3339(),
                 "2019-08-01T11:52:36.25600005Z"
             );
         }
